@@ -543,6 +543,16 @@ typedef enum {
  * Since: 1.8.11
  */
 #define FWUPD_DEVICE_FLAG_EMULATION_TAG (1llu << 50)
+/**
+ * FWUPD_DEVICE_FLAG_ONLY_EXPLICIT_UPDATES:
+ *
+ * The device should stay on one firmware version unless the new version is explicitly specified.
+ *
+ * This can either be done using `fwupdmgr install`, using GNOME Firmware, or using a BKC config.
+ *
+ * Since: 1.9.3
+ */
+#define FWUPD_DEVICE_FLAG_ONLY_EXPLICIT_UPDATES (1llu << 51)
 /**
  * FWUPD_DEVICE_FLAG_UNKNOWN:
  *
@@ -655,6 +665,14 @@ typedef guint64 FwupdDeviceFlags;
  * Since 1.9.1
  */
 #define FWUPD_DEVICE_PROBLEM_IN_USE (1llu << 10)
+/**
+ * FWUPD_DEVICE_PROBLEM_DISPLAY_REQUIRED:
+ *
+ * The device cannot be used while there are no displays plugged in.
+ *
+ * Since 1.9.6
+ */
+#define FWUPD_DEVICE_PROBLEM_DISPLAY_REQUIRED (1llu << 11)
 /**
  * FWUPD_DEVICE_PROBLEM_UNKNOWN:
  *
@@ -935,6 +953,23 @@ typedef enum {
  * Since: 1.8.7
  */
 #define FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY (1llu << 15)
+/**
+ * FWUPD_PLUGIN_FLAG_ESP_NOT_VALID:
+ *
+ * The plugins discovered that the EFI system partition may not be valid.
+ * Supported clients will display this information to a user.
+ *
+ * Since: 1.9.3
+ */
+#define FWUPD_PLUGIN_FLAG_ESP_NOT_VALID (1llu << 16)
+/**
+ * FWUPD_PLUGIN_FLAG_READY:
+ *
+ * The plugin is ready for use and all devices have been coldplugged.
+ *
+ * Since: 1.9.6
+ */
+#define FWUPD_PLUGIN_FLAG_READY (1llu << 17)
 /**
  * FWUPD_PLUGIN_FLAG_UNKNOWN:
  *
