@@ -45,10 +45,36 @@ typedef enum {
 	FWUPD_REMOTE_KIND_LAST
 } FwupdRemoteKind;
 
+/**
+ * FwupdRemoteFlags:
+ * @FWUPD_REMOTE_FLAG_NONE:				No flags set
+ * @FWUPD_REMOTE_FLAG_ENABLED:				Is enabled
+ * @FWUPD_REMOTE_FLAG_APPROVAL_REQUIRED:		Requires approval for each firmware
+ * @FWUPD_REMOTE_FLAG_AUTOMATIC_REPORTS:		Send firmware reports automatically
+ * @FWUPD_REMOTE_FLAG_AUTOMATIC_SECURITY_REPORTS:	Send security reports automatically
+ * @FWUPD_REMOTE_FLAG_ALLOW_P2P_METADATA:		Use peer-to-peer locations for metadata
+ * @FWUPD_REMOTE_FLAG_ALLOW_P2P_FIRMWARE:		Use peer-to-peer locations for firmware
+ *
+ * The flags available for the remote.
+ **/
+typedef enum {
+	FWUPD_REMOTE_FLAG_NONE = 0,			       /* Since: 1.9.4 */
+	FWUPD_REMOTE_FLAG_ENABLED = 1 << 0,		       /* Since: 1.9.4 */
+	FWUPD_REMOTE_FLAG_APPROVAL_REQUIRED = 1 << 1,	       /* Since: 1.9.4 */
+	FWUPD_REMOTE_FLAG_AUTOMATIC_REPORTS = 1 << 2,	       /* Since: 1.9.4 */
+	FWUPD_REMOTE_FLAG_AUTOMATIC_SECURITY_REPORTS = 1 << 3, /* Since: 1.9.4 */
+	FWUPD_REMOTE_FLAG_ALLOW_P2P_METADATA = 1 << 4,	       /* Since: 1.9.5 */
+	FWUPD_REMOTE_FLAG_ALLOW_P2P_FIRMWARE = 1 << 5,	       /* Since: 1.9.5 */
+} FwupdRemoteFlags;
+
 FwupdRemoteKind
 fwupd_remote_kind_from_string(const gchar *kind);
 const gchar *
 fwupd_remote_kind_to_string(FwupdRemoteKind kind);
+const gchar *
+fwupd_remote_flag_to_string(FwupdRemoteFlags flag);
+FwupdRemoteFlags
+fwupd_remote_flag_from_string(const gchar *flag);
 
 FwupdRemote *
 fwupd_remote_new(void);
@@ -63,6 +89,8 @@ fwupd_remote_get_remotes_dir(FwupdRemote *self);
 const gchar *
 fwupd_remote_get_checksum(FwupdRemote *self);
 const gchar *
+fwupd_remote_get_checksum_metadata(FwupdRemote *self);
+const gchar *
 fwupd_remote_get_username(FwupdRemote *self);
 const gchar *
 fwupd_remote_get_password(FwupdRemote *self);
@@ -82,14 +110,34 @@ const gchar *
 fwupd_remote_get_metadata_uri(FwupdRemote *self);
 const gchar *
 fwupd_remote_get_metadata_uri_sig(FwupdRemote *self);
+G_DEPRECATED_FOR(fwupd_remote_has_flag)
 gboolean
 fwupd_remote_get_enabled(FwupdRemote *self);
+G_DEPRECATED_FOR(fwupd_remote_has_flag)
 gboolean
 fwupd_remote_get_approval_required(FwupdRemote *self);
+G_DEPRECATED_FOR(fwupd_remote_has_flag)
 gboolean
 fwupd_remote_get_automatic_reports(FwupdRemote *self);
+G_DEPRECATED_FOR(fwupd_remote_has_flag)
 gboolean
 fwupd_remote_get_automatic_security_reports(FwupdRemote *self);
+guint64
+fwupd_remote_get_refresh_interval(FwupdRemote *self);
+
+FwupdRemoteFlags
+fwupd_remote_get_flags(FwupdRemote *self);
+void
+fwupd_remote_set_flags(FwupdRemote *self, FwupdRemoteFlags flags);
+void
+fwupd_remote_add_flag(FwupdRemote *self, FwupdRemoteFlags flag);
+void
+fwupd_remote_remove_flag(FwupdRemote *self, FwupdRemoteFlags flag);
+gboolean
+fwupd_remote_has_flag(FwupdRemote *self, FwupdRemoteFlags flag);
+
+gboolean
+fwupd_remote_needs_refresh(FwupdRemote *self);
 gint
 fwupd_remote_get_priority(FwupdRemote *self);
 guint64
