@@ -39,6 +39,8 @@ struct _FwupdSecurityAttrClass {
  * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM:	Contact the firmware vendor for a update
  * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW:		Failure may be fixed by changing FW config
  * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS:		Failure may be fixed by changing OS config
+ * @FWUPD_SECURITY_ATTR_FLAG_CAN_FIX:			The failure can be automatically fixed
+ * @FWUPD_SECURITY_ATTR_FLAG_CAN_UNDO:			The fix can be automatically reverted
  *
  * The flags available for HSI attributes.
  **/
@@ -53,6 +55,8 @@ typedef enum {
 	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM = 1 << 11,
 	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW = 1 << 12,
 	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS = 1 << 13,
+	FWUPD_SECURITY_ATTR_FLAG_CAN_FIX = 1 << 14,
+	FWUPD_SECURITY_ATTR_FLAG_CAN_UNDO = 1 << 15,
 } FwupdSecurityAttrFlags;
 
 /**
@@ -126,6 +130,27 @@ fwupd_security_attr_new(const gchar *appstream_id);
 gchar *
 fwupd_security_attr_to_string(FwupdSecurityAttr *self);
 
+const gchar *
+fwupd_security_attr_get_bios_setting_id(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_bios_setting_id(FwupdSecurityAttr *self, const gchar *id);
+const gchar *
+fwupd_security_attr_get_bios_setting_target_value(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_bios_setting_target_value(FwupdSecurityAttr *self, const gchar *value);
+const gchar *
+fwupd_security_attr_get_bios_setting_current_value(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_bios_setting_current_value(FwupdSecurityAttr *self, const gchar *value);
+const gchar *
+fwupd_security_attr_get_kernel_current_value(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_kernel_current_value(FwupdSecurityAttr *self, const gchar *value);
+const gchar *
+fwupd_security_attr_get_kernel_target_value(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_kernel_target_value(FwupdSecurityAttr *self, const gchar *value);
+
 const gchar *
 fwupd_security_attr_get_appstream_id(FwupdSecurityAttr *self);
 void
@@ -138,6 +163,14 @@ FwupdSecurityAttrResult
 fwupd_security_attr_get_result(FwupdSecurityAttr *self);
 void
 fwupd_security_attr_set_result(FwupdSecurityAttr *self, FwupdSecurityAttrResult result);
+FwupdSecurityAttrResult
+fwupd_security_attr_get_result_fallback(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_result_fallback(FwupdSecurityAttr *self, FwupdSecurityAttrResult result);
+FwupdSecurityAttrResult
+fwupd_security_attr_get_result_success(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_result_success(FwupdSecurityAttr *self, FwupdSecurityAttrResult result);
 const gchar *
 fwupd_security_attr_get_name(FwupdSecurityAttr *self);
 void
